#version 330 core
struct Material {
    vec3 ambientColour;
    vec3 diffuseColour;
    vec3 specularColour;
    float shininess;
};
struct Light {
    vec3 position;
  
    vec3 ambientIntensity;
    vec3 diffuseIntensity;
    vec3 specularIntensity;
};

out vec4 FragColor;

uniform vec3 lightPosition, viewPosition;
uniform Material material;
uniform Light light;

in vec3 FragmentPos;
in vec3 Normal;

void main()
{
	vec3 normal = normalize(Normal);

	vec3 ambientLight = light.ambientIntensity * material.ambientColour;

	vec3 lightDir = normalize(lightPosition - FragmentPos);
	float diff = max(dot(normal, lightDir), 0.0);
	vec3 diffuseLight = light.diffuseIntensity * (diff * material.diffuseColour);

	vec3 viewDir = normalize(viewPosition - FragmentPos);
	vec3 reflectDir = reflect(-lightDir, normal);
	float spec = pow(max(dot(viewDir, reflectDir), 0.0), material.shininess);
	vec3 specularLight = light.specularIntensity * (spec * material.specularColour);

	vec3 result = ambientLight + diffuseLight + specularLight;
	FragColor = vec4(result, 1.0);
} 